@@ -89,14 +89,15 @@ etl.default <- function(x, db = NULL, dir = tempdir(), ...) {
   }
   db <- verify_con(db, dir)
   obj <- structure(db, data = NULL, "pkg" = pkg, dir = normalizePath(dir),
-              files = NULL, push = NULL, class = c(paste0("etl_", x), "etl", class(db)))
+                   files = NULL, push = NULL,
+                   class = c(paste0("etl_", x), "etl", class(db)))
 
   # create subdirectories within dir
-  raw_dir <- paste0(attr(obj, "dir"), "/raw")
+  raw_dir <- file.path(attr(obj, "dir"), "raw")
   if (!dir.exists(raw_dir)) {
     dir.create(raw_dir)
   }
-  load_dir <- paste0(attr(obj, "dir"), "/load")
+  load_dir <- file.path(attr(obj, "dir"), "load")
   if (!dir.exists(load_dir)) {
     dir.create(load_dir)
   }
@@ -149,7 +150,7 @@ is.etl <- function(object) inherits(object, "etl")
 #' @rdname etl
 #' @export
 #' @inheritParams base::print
-#' @importFrom tidyr extract_numeric
+#' @importFrom readr parse_number
 #' @examples
 #' cars <- etl("mtcars") %>%
 #'   etl_create()
@@ -159,7 +160,8 @@ print.etl <- function(x, ...) {
   file_info <- dplyr::bind_rows(
     summary_dir(attr(x, "raw_dir")),
     summary_dir(attr(x, "load_dir"))) %>%
-    summarize_(N = ~sum(n), size = ~sum(tidyr::extract_numeric(size)))
-  cat("dir:  ", file_info$N, " files occupying ", file_info$size, " GB\n", sep = "")
+    summarize_(N = ~sum(n), size = ~sum(readr::parse_number(size)))
+  cat("dir:  ", file_info$N, " files occupying ",
+      file_info$size, " GB\n", sep = "")
   NextMethod()
 }
