@@ -9,7 +9,8 @@ etl_transform <- function(obj, ...) UseMethod("etl_transform")
 
 etl_transform.default <- function(obj, ...) {
   # load the data and process it if necessary
-  message(paste0("No available methods. Did you write the method etl_transform.", class(obj)[1]), "()?")
+  message(paste0("No available methods. Did you write the method
+                 etl_transform.", class(obj)[1]), "()?")
   invisible(obj)
 }
 
@@ -20,11 +21,11 @@ etl_transform.default <- function(obj, ...) {
 
 etl_transform.etl_mtcars <- function(obj, ...) {
   message("Transforming raw data...")
-  src <- paste0(attr(obj, "raw_dir"), "/mtcars.csv")
+  src <- file.path(attr(obj, "raw_dir"), "mtcars.csv")
   data <- utils::read.csv(src)
   data <- data %>%
     rename_(makeModel = ~X)
-  lcl <- paste0(attr(obj, "load_dir"), "/mtcars.csv")
+  lcl <- file.path(attr(obj, "load_dir"), "mtcars.csv")
   utils::write.csv(data, file = lcl, row.names = FALSE)
   invisible(obj)
 }
